==> create-flask-skeleton-0.1.2.tar.gz: create-flask-skeleton-0.1.2/setup.py <==
# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['create_flask_skeleton',
 'create_flask_skeleton.template.app',
 'create_flask_skeleton.template.app.apps',
 'create_flask_skeleton.template.tests']

package_data = \
{'': ['*'],
 'create_flask_skeleton': ['template/.flake8',
                           'template/.flake8',
                           'template/.flake8',
                           'template/.flake8',
                           'template/.flake8',
                           'template/.flake8',
                           'template/.flake8',
                           'template/.flake8',
                           'template/.flake8',
                           'template/.flaskenv',
                           'template/.flaskenv',
                           'template/.flaskenv',
                           'template/.flaskenv',
                           'template/.flaskenv',
                           'template/.flaskenv',
                           'template/.flaskenv',
                           'template/.flaskenv',
                           'template/.flaskenv',
                           'template/.gitignore',
                           'template/.gitignore',
                           'template/.gitignore',
                           'template/.gitignore',
                           'template/.gitignore',
                           'template/.gitignore',
                           'template/.gitignore',
                           'template/.gitignore',
                           'template/.gitignore',
                           'template/.pre-commit-config.yaml',
                           'template/.pre-commit-config.yaml',
                           'template/.pre-commit-config.yaml',
                           'template/.pre-commit-config.yaml',
                           'template/.pre-commit-config.yaml',
                           'template/.pre-commit-config.yaml',
                           'template/.pre-commit-config.yaml',
                           'template/.pre-commit-config.yaml',
                           'template/.pre-commit-config.yaml',
                           'template/LICENSE',
                           'template/LICENSE',
                           'template/LICENSE',
                           'template/LICENSE',
                           'template/LICENSE',
                           'template/LICENSE',
                           'template/LICENSE',
                           'template/LICENSE',
                           'template/LICENSE',
                           'template/Makefile',
                           'template/Makefile',
                           'template/Makefile',
                           'template/Makefile',
                           'template/Makefile',
                           'template/Makefile',
                           'template/Makefile',
                           'template/Makefile',
                           'template/Makefile',
                           'template/README.md',
                           'template/README.md',
                           'template/README.md',
                           'template/README.md',
                           'template/README.md',
                           'template/README.md',
                           'template/README.md',
                           'template/README.md',
                           'template/README.md',
                           'template/mypy.ini',
                           'template/mypy.ini',
                           'template/mypy.ini',
                           'template/mypy.ini',
                           'template/mypy.ini',
                           'template/mypy.ini',
                           'template/mypy.ini',
                           'template/mypy.ini',
                           'template/mypy.ini',
                           'template/pyproject.toml',
                           'template/pyproject.toml',
                           'template/pyproject.toml',
                           'template/pyproject.toml',
                           'template/pyproject.toml',
                           'template/pyproject.toml',
                           'template/pyproject.toml',
                           'template/pyproject.toml',
                           'template/pyproject.toml'],
 'create_flask_skeleton.template.app': ['static/*', 'templates/*']}

install_requires = \
['click>=7.0,<8.0', 'jinja2>=2.10,<3.0']

entry_points = \
{'console_scripts': ['create-flask-skeleton = create_flask_skeleton:main']}

setup_kwargs = {
    'name': 'create-flask-skeleton',
    'version': '0.1.2',
    'description': '',
    'long_description': None,
    'author': 'Ryan Wang',
    'author_email': 'hwwangwang@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)

==> create-flask-skeleton-0.1.3.tar.gz: create-flask-skeleton-0.1.3/setup.py <==
# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['create_flask_skeleton',
 'create_flask_skeleton.template.app',
 'create_flask_skeleton.template.app.apps',
 'create_flask_skeleton.template.tests']

package_data = \
{'': ['*'],
 'create_flask_skeleton': ['template/.flake8',
                           'template/.flake8',
                           'template/.flake8',
                           'template/.flake8',
                           'template/.flake8',
                           'template/.flake8',
                           'template/.flake8',
                           'template/.flake8',
                           'template/.flake8',
                           'template/.flaskenv',
                           'template/.flaskenv',
                           'template/.flaskenv',
                           'template/.flaskenv',
                           'template/.flaskenv',
                           'template/.flaskenv',
                           'template/.flaskenv',
                           'template/.flaskenv',
                           'template/.flaskenv',
                           'template/.gitignore',
                           'template/.gitignore',
                           'template/.gitignore',
                           'template/.gitignore',
                           'template/.gitignore',
                           'template/.gitignore',
                           'template/.gitignore',
                           'template/.gitignore',
                           'template/.gitignore',
                           'template/.pre-commit-config.yaml',
                           'template/.pre-commit-config.yaml',
                           'template/.pre-commit-config.yaml',
                           'template/.pre-commit-config.yaml',
                           'template/.pre-commit-config.yaml',
                           'template/.pre-commit-config.yaml',
                           'template/.pre-commit-config.yaml',
                           'template/.pre-commit-config.yaml',
                           'template/.pre-commit-config.yaml',
                           'template/LICENSE',
                           'template/LICENSE',
                           'template/LICENSE',
                           'template/LICENSE',
                           'template/LICENSE',
                           'template/LICENSE',
                           'template/LICENSE',
                           'template/LICENSE',
                           'template/LICENSE',
                           'template/Makefile',
                           'template/Makefile',
                           'template/Makefile',
                           'template/Makefile',
                           'template/Makefile',
                           'template/Makefile',
                           'template/Makefile',
                           'template/Makefile',
                           'template/Makefile',
                           'template/README.md',
                           'template/README.md',
                           'template/README.md',
                           'template/README.md',
                           'template/README.md',
                           'template/README.md',
                           'template/README.md',
                           'template/README.md',
                           'template/README.md',
                           'template/mypy.ini',
                           'template/mypy.ini',
                           'template/mypy.ini',
                           'template/mypy.ini',
                           'template/mypy.ini',
                           'template/mypy.ini',
                           'template/mypy.ini',
                           'template/mypy.ini',
                           'template/mypy.ini',
                           'template/pyproject.toml',
                           'template/pyproject.toml',
                           'template/pyproject.toml',
                           'template/pyproject.toml',
                           'template/pyproject.toml',
                           'template/pyproject.toml',
                           'template/pyproject.toml',
                           'template/pyproject.toml',
                           'template/pyproject.toml'],
 'create_flask_skeleton.template.app': ['static/*', 'templates/*']}

install_requires = \
['click>=7.0,<8.0', 'jinja2>=2.10,<3.0']

entry_points = \
{'console_scripts': ['create-flask-skeleton = create_flask_skeleton:main']}

setup_kwargs = {
    'name': 'create-flask-skeleton',
    'version': '0.1.3',
    'description': 'Quick bootstrap A Flask Project',
    'long_description': '# create-flask-skeleton\n\nQuick bootstrap A new flask project.\n\n- 🔥 Minimal boilerplate\n- 🐍 Modern Python Toolchain (Black, Flake8, Mypy, Pytest)\n- 🎗 CORS support on the fly\n- 🔧 Basic JWT auth with different audience\n- 💽 Data Validation by Volupulous\n\n\n## Only python3.7 and above are supported.\n\n## Install\n\n    pip3 install create-flask-skeleton\n\n## Quick start a flask project\n\n    create-flask-skeleton yourappname\n\n\n',
    'author': 'Ryan Wang',
    'author_email': 'hwwangwang@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/moonshadow/create-flask-skeleton/',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
